@@ -10,7 +10,7 @@ from stackifyapm.utils.helper import is_async_span
 from stackifyapm.traces import execution_context
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("stackifyapm.instrument")
 
 
 class CustomInstrumentation(AbstractInstrumentedModule):
