@@ -1,7 +1,7 @@
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
 from stackifyapm.traces import CaptureSpan
 from stackifyapm.traces import DroppedSpan
-from stackifyapm.traces import get_transaction
+from stackifyapm.traces import execution_context
 from stackifyapm.utils.helper import is_async_span
 
 
@@ -15,7 +15,6 @@ class Urllib2Instrumentation(AbstractInstrumentedModule):
 
     def call(self, module, method, wrapped, instance, args, kwargs):
         url = args[0]
-        signature = method.upper() + " " + url
         extra_data = {
             "wrapped_method": "Execute",
             "provider": self.name,
@@ -24,7 +23,7 @@ class Urllib2Instrumentation(AbstractInstrumentedModule):
             "url": url,
         }
 
-        with CaptureSpan(signature, "ext.http.urllib2", extra_data, leaf=True, is_async=is_async_span()) as span:
+        with CaptureSpan("ext.http.urllib2", extra_data, leaf=True, is_async=is_async_span()) as span:
             request = wrapped(*args, **kwargs)
 
             if not isinstance(span, DroppedSpan):
@@ -32,7 +31,7 @@ class Urllib2Instrumentation(AbstractInstrumentedModule):
                 if hasattr(request, '_method'):
                     span.context['request_method'] = request._method
 
-                transaction = get_transaction()
+                transaction = execution_context.get_transaction()
                 transaction.update_span_context(span.id, span.context)
 
             return request
