@@ -8,7 +8,7 @@ except Exception:
     import mock
 
 from stackifyapm.base import Client
-from stackifyapm.traces import get_transaction
+from stackifyapm.traces import execution_context
 from stackifyapm.instrumentation import register
 from stackifyapm.instrumentation import control
 
@@ -99,7 +99,7 @@ class CustomInstrumentationTest(TestCase):
 
     def tearDown(self):
         control.uninstrument(client=self.client)
-        get_transaction(clear=True)
+        execution_context.get_transaction(clear=True)
         os.remove(STACKIFY_JSON_FILE)
 
     def test_basic_custom_instrumentation(self):
@@ -138,7 +138,7 @@ class CustomInstrumentationTest(TestCase):
         )
 
     def assert_span(self, call=None, tracked_func=None, extra=None):
-        transaction = get_transaction()
+        transaction = execution_context.get_transaction()
         assert transaction
         assert transaction.get_spans()
 
@@ -164,66 +164,69 @@ class CustomTransactionInstrumentationTest(TestCase):
             with open(STACKIFY_JSON_FILE, 'w') as json_file:
                 json.dump(INSTRUMENTATION, json_file)
 
-        self.client = Client(CONFIG)
         register._cls_registers = {
             "stackifyapm.instrumentation.packages.custom.CustomInstrumentation",
         }
 
         # making sure we clear transaction
-        get_transaction(clear=True)
+        execution_context.get_transaction(clear=True)
 
     def tearDown(self):
         control.uninstrument(client=self.client)
         os.remove(STACKIFY_JSON_FILE)
 
-    @mock.patch("stackifyapm.base.Client.transaction_handler")
-    def test_custom_transaction_instrumentation(self, transaction_handler_mock):
+    @mock.patch("stackifyapm.base.Client.queue")
+    def test_custom_transaction_instrumentation(self, queue_mock):
+        self.client = Client(CONFIG)
         control.instrument(client=self.client)
 
         CustomClassSix().custom_method_six()
 
-        assert transaction_handler_mock.called
+        assert queue_mock.called
         self.assert_transaction(
-            transaction=transaction_handler_mock.call_args_list[0][0][0],
+            transaction=queue_mock.call_args_list[0][0][0],
             call="custom.CustomClassSix.custom_method_six",
             stacks_count=0,
         )
 
-    @mock.patch("stackifyapm.base.Client.transaction_handler")
-    def test_custom_transaction_instrumentation_with_custom_span(self, transaction_handler_mock):
+    @mock.patch("stackifyapm.base.Client.queue")
+    def test_custom_transaction_instrumentation_with_custom_span(self, queue_mock):
+        self.client = Client(CONFIG)
         control.instrument(client=self.client)
 
         CustomClassSeven().custom_method_seven()
 
-        assert transaction_handler_mock.called
+        assert queue_mock.called
 
         self.assert_transaction(
-            transaction=transaction_handler_mock.call_args_list[0][0][0],
+            transaction=queue_mock.call_args_list[0][0][0],
             call="custom.CustomClassSeven.custom_method_seven",
             stacks_count=1,
         )
         self.assert_span_from_transaction(
-            transaction=transaction_handler_mock.call_args_list[0][0][0],
+            transaction=queue_mock.call_args_list[0][0][0],
             call='custom.CustomClassOne.custom_method_one'
         )
 
-    @mock.patch("stackifyapm.base.Client.transaction_handler")
-    def test_custom_transaction_instrumentation_with_exception(self, transaction_handler_mock):
+    @mock.patch("stackifyapm.base.Client.queue")
+    def test_custom_transaction_instrumentation_with_exception(self, queue_mock):
+        self.client = Client(CONFIG)
         control.instrument(client=self.client)
 
         with self.assertRaises(Exception):
             CustomClassEight().custom_method_eight()
 
-        assert transaction_handler_mock.called
+        assert queue_mock.called
 
         self.assert_transaction(
-            transaction=transaction_handler_mock.call_args_list[0][0][0],
+            transaction=queue_mock.call_args_list[0][0][0],
             call="custom.CustomClassEight.custom_method_eight",
             stacks_count=0,
             exception=True
         )
 
     def test_custom_transaction_instrumentation_but_transaction_already_exists(self):
+        self.client = Client(CONFIG)
         control.instrument(client=self.client)
         self.client.begin_transaction("transaction_test")
 
@@ -234,7 +237,7 @@ class CustomTransactionInstrumentationTest(TestCase):
     def assert_transaction(self, transaction, call=None, stacks_count=0, exception=False):
         assert transaction
 
-        transaction_data = json.loads(transaction.to_dict())
+        transaction_data = transaction.to_dict()
 
         assert transaction_data["id"]
         assert transaction_data["call"] == call
@@ -259,7 +262,7 @@ class CustomTransactionInstrumentationTest(TestCase):
             assert transaction_data["exceptions"][0]["Message"] == "Some exception"
 
     def assert_span(self, call=None):
-        transaction = get_transaction()
+        transaction = execution_context.get_transaction()
         assert transaction
         assert transaction.get_spans()
 
@@ -271,7 +274,7 @@ class CustomTransactionInstrumentationTest(TestCase):
     def assert_span_from_transaction(self, transaction, call):
         assert transaction
 
-        transaction_data = json.loads(transaction.to_dict())
+        transaction_data = transaction.to_dict()
         span_data = transaction_data['stacks'][0]
 
         self.assert_span_data(span_data=span_data, call=call)
