@@ -55,28 +55,28 @@ class RequestInstrumentationTest(TestCase):
 
         requests.get('http://www.python.org/')
 
-        self.assert_span(method='GET', status=200)
+        self.assert_span(method='GET', status="200")
 
     def test_unsuccessful_get_request(self):
         self.setUpFailed()
 
         requests.get('http://www.python.org/')
 
-        self.assert_span(method='GET', status=400)
+        self.assert_span(method='GET', status="400")
 
     def test_successful_post_request(self):
         self.setUpSuccess()
 
         requests.post('http://www.python.org/')
 
-        self.assert_span(method='POST', status=200)
+        self.assert_span(method='POST', status="200")
 
     def test_unsuccessful_post_request(self):
         self.setUpFailed()
 
         requests.post('http://www.python.org/')
 
-        self.assert_span(method='POST', status=400)
+        self.assert_span(method='POST', status="400")
 
     def assert_span(self, method, status):
         transaction = execution_context.get_transaction()
