@@ -53,14 +53,12 @@ class MyThread(threading.Thread):
 
 class ThreadInstrumentationTest(TestCase):
 
-    def set_up(self, multiprocessing=False):
+    def set_up(self, request_mock, multiprocessing=False):
         CONFIG["MULTIPROCESSING"] = multiprocessing
         self.client = Client(CONFIG)
-        self.http_response = Response()
-        self.http_response.status_code = 200
-        self.request_get = mock.patch('requests.adapters.HTTPAdapter.build_response')
-        self.request_mock = self.request_get.start()
-        self.request_mock.return_value = self.http_response
+        http_response = Response()
+        http_response.status_code = 200
+        request_mock.return_value = http_response
 
         register._cls_registers = {
             "stackifyapm.instrumentation.packages.requests.RequestsInstrumentation",
@@ -71,10 +69,10 @@ class ThreadInstrumentationTest(TestCase):
 
     def tearDown(self):
         control.uninstrument()
-        self.request_get.stop()
 
-    def test_should_update_transaction_if_using__thread_module(self):
-        self.set_up()
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_should_update_transaction_if_using__thread_module(self, request_mock):
+        self.set_up(request_mock)
         _thread.start_new_thread(do_something, ())
 
         time.sleep(1)
@@ -82,9 +80,10 @@ class ThreadInstrumentationTest(TestCase):
 
         assert transaction.get_has_async_spans()
 
-    def test_should_update_transaction_if_using_threading_module(self):
-        self.set_up()
-        thread = MyThread()
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_should_update_transaction_if_using_threading_module(self, request_mock):
+        self.set_up(request_mock)
+        thread = MyThread('https://www.python.org/')
         thread.start()
         thread.join()
 
@@ -92,8 +91,9 @@ class ThreadInstrumentationTest(TestCase):
 
         assert transaction.get_has_async_spans()
 
-    def test_should_update_transaction_if_using_multiprocessing_module(self):
-        self.set_up()
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_should_update_transaction_if_using_multiprocessing_module(self, request_mock):
+        self.set_up(request_mock)
         p = Process(target=do_requests, args=('https://www.python.org/',))
         p.start()
         p.join()
@@ -101,16 +101,18 @@ class ThreadInstrumentationTest(TestCase):
         transaction = execution_context.get_transaction()
         assert transaction.get_has_async_spans()
 
-    def test_should_add_async_span_in_transaction_using_thread_module(self):
-        self.set_up()
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_should_add_async_span_in_transaction_using_thread_module(self, request_mock):
+        self.set_up(request_mock)
         _thread.start_new_thread(do_requests, ('http://www.python.org/',))
 
         time.sleep(1)
 
         assert_span()
 
-    def test_multiprocessing_config_is_False(self):
-        self.set_up()
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_multiprocessing_config_is_False(self, request_mock):
+        self.set_up(request_mock)
         p = Process(target=do_requests, args=('http://www.python.org/',))
         p.start()
         p.join()
@@ -119,8 +121,9 @@ class ThreadInstrumentationTest(TestCase):
 
         assert_span(False)
 
-    def test_multiprocessing_config_is_True(self):
-        self.set_up(multiprocessing=True)
+    @mock.patch('requests.adapters.HTTPAdapter.build_response')
+    def test_multiprocessing_config_is_True(self, request_mock):
+        self.set_up(request_mock, multiprocessing=True)
         p = Process(target=do_requests, args=('http://www.python.org/',))
         p.start()
         p.join()
@@ -154,7 +157,7 @@ def assert_span(span=True):
     assert span_data['props']['COMPONENT_CATEGORY'] == 'Web External'
     assert span_data['props']['COMPONENT_DETAIL'] == 'Execute'
     assert span_data['props']['URL'] == 'http://www.python.org/'
-    assert span_data['props']['STATUS'] == 200
+    assert span_data['props']['STATUS'] == '200'
     assert span_data['props']['METHOD'] == 'GET'
     assert span_data['props']['TRACETYPE'] == 'ASYNC'
     assert span_data['props']['THREAD_ID']
