@@ -1,6 +1,6 @@
-import json
 from unittest import TestCase
 
+import stackifyapm
 from stackifyapm.base import Client
 from stackifyapm.traces import CaptureSpan
 from stackifyapm.traces import DroppedSpan
@@ -44,21 +44,19 @@ class TransactionTest(TestCase):
 
     def test_begin_span(self):
         transaction = Transaction("request", None, meta_data=self.client.get_meta_data())
-        span = transaction.begin_span('test_span', 'test_span_type', context={}, leaf=False)
+        span = transaction.begin_span('test_span_type', context={}, leaf=False)
 
         assert span
-        assert span.name == 'test_span'
         assert span.start_time
         assert not span.end_time
         assert span == execution_context.get_span()
 
     def test_end_span(self):
         transaction = Transaction("request", None, meta_data=self.client.get_meta_data())
-        transaction.begin_span('test_span', 'test_span_type', context={}, leaf=False)
+        transaction.begin_span('test_span_type', context={}, leaf=False)
         span = transaction.end_span()
 
         assert span
-        assert span.name == 'test_span'
         assert span.start_time
         assert span.end_time
         assert not execution_context.get_span()
@@ -85,12 +83,13 @@ class TransactionTest(TestCase):
         trace_parent = TraceParent("2.0", "some_id", None)
 
         transaction = Transaction("request", trace_parent, meta_data=self.client.get_meta_data())
-        transaction.begin_span("postgres", "database", context=context, leaf=False)
+        transaction.begin_span("database", context=context, leaf=False)
         transaction.add_exception('some exception')
         transaction.end_span()
-        transaction_dict = json.loads(transaction.to_dict())
+        transaction_dict = transaction.to_dict()
 
         assert transaction_dict["props"]
+        assert transaction_dict["props"]["PROFILER_VERSION"] == stackifyapm.__version__
         assert transaction_dict["props"]["CATEGORY"] == "Python"
         assert transaction_dict["props"]["APPLICATION_FILESYSTEM_PATH"] == "path/to/application/"
         assert transaction_dict["props"]["APPLICATION_NAME"] == "sample_application"
@@ -111,7 +110,7 @@ class TransactionTest(TestCase):
                 "method": "get"
             }
         }
-        transaction_dict = json.loads(transaction.to_dict())
+        transaction_dict = transaction.to_dict()
 
         assert transaction_dict["props"]
         assert transaction_dict["props"]["METHOD"] == "get"
@@ -127,21 +126,21 @@ class TransactionTest(TestCase):
                 "status_code": 200,
             }
         }
-        transaction_dict = json.loads(transaction.to_dict())
+        transaction_dict = transaction.to_dict()
 
         assert transaction_dict["props"]
-        assert transaction_dict["props"]["STATUS"] == 200
+        assert transaction_dict["props"]["STATUS"] == "200"
 
     def test_multiple_span(self):
         trace_parent = TraceParent("2.0", "some_id", None)
 
         transaction = Transaction("request", trace_parent, meta_data=self.client.get_meta_data())
-        transaction.begin_span('test_span', 'test_span_type', context={}, leaf=False)
+        transaction.begin_span('test_span_type', context={}, leaf=False)
         transaction.end_span()
-        transaction.begin_span('test_span', 'test_span_type', context={}, leaf=False)
+        transaction.begin_span('test_span_type', context={}, leaf=False)
         transaction.end_span()
 
-        transaction_dict = json.loads(transaction.to_dict())
+        transaction_dict = transaction.to_dict()
 
         assert len(transaction_dict['stacks']) == 2
 
@@ -149,12 +148,12 @@ class TransactionTest(TestCase):
         trace_parent = TraceParent("2.0", "some_id", None)
 
         transaction = Transaction("request", trace_parent, meta_data=self.client.get_meta_data())
-        transaction.begin_span('test_span', 'test_span_type_1', context={}, leaf=False)
-        transaction.begin_span('test_span', 'test_span_type_2', context={}, leaf=False)
+        transaction.begin_span('test_span_type_1', context={}, leaf=False)
+        transaction.begin_span('test_span_type_2', context={}, leaf=False)
         transaction.end_span()
         transaction.end_span()
 
-        transaction_dict = json.loads(transaction.to_dict())
+        transaction_dict = transaction.to_dict()
 
         assert len(transaction_dict['stacks']) == 1
         assert transaction_dict['stacks'][0]['call'] == 'test_span_type_1'
@@ -173,12 +172,11 @@ class SpanTest(TestCase):
         execution_context.clear_span()
 
     def test_span_creation(self):
-        span = Span(self.transaction, 'span_test', 'span_test_type', context={}, leaf=False)
+        span = Span(self.transaction, 'span_test_type', context={}, leaf=False)
         assert span
         assert span.id
         assert span.start_time
         assert not span.end_time
-        assert span.name == 'span_test'
         assert span.type == 'span_test_type'
 
     def test_to_dict(self):
@@ -190,7 +188,7 @@ class SpanTest(TestCase):
             "statement": "Select * from sample",
             "row_count": 1,
         }
-        span = Span(self.transaction, 'db.sample_database', 'database', context=context, leaf=False)
+        span = Span(self.transaction, 'database', context=context, leaf=False)
         span_dict = span.to_dict()
 
         assert span_dict['id']
@@ -207,7 +205,7 @@ class SpanTest(TestCase):
         assert span_dict['props']['ROW_COUNT'] == 1
 
     def test_to_dict_with_no_context(self):
-        span = Span(self.transaction, 'db.sample_database', 'others', context={}, leaf=False)
+        span = Span(self.transaction, 'others', context={}, leaf=False)
         span_dict = span.to_dict()
 
         assert span_dict['id']
@@ -272,14 +270,13 @@ class CaptureSpanTest(TestCase):
 
     def test_capture_span_creation(self):
         self.tracer.begin_transaction('request', None, self.client)
-        with CaptureSpan(name='span_test', span_type="span_test_type", extra={'provider': 'stackify_test'}, leaf=False):
+        with CaptureSpan(span_type="span_test_type", extra={'provider': 'stackify_test'}, leaf=False):
             pass
 
         transaction = execution_context.get_transaction()
 
         assert transaction
         assert len(transaction.get_spans()) == 1
-        assert transaction.get_spans()[0].name == 'span_test'
 
     def test_decorator_span(self):
         self.tracer.begin_transaction('request', None, self.client)
